<?php
namespace Teknisa\CADFIS\Controllers;

use Teknisa\Libs\Util\Environment;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;

class Municipio extends \Teknisa\CADFIS\Controllers\TeknisaCrud {

    protected $dataSourceName = "municipio";

    public function __construct($crudService, ParameterBag $parameterBag, Environment $environment, $ger01500municipioservice, $fileServerUrl) {
        parent::__construct($crudService, $parameterBag);
        $this->environment = $environment;
        $this->ger01500municipioservice = $ger01500municipioservice;
        $this->fileServerUrl = $fileServerUrl;
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $nrorgLogada = $this->environment->getNrOrgTrab();
            $filterCriteria = $request->getFilterCriteria();
            $filterCriteria->setDataSourceName($this->dataSourceName);
            $filterCriteria->addCondition('NRORG', 'IN', array($nrorgLogada, 0));
            $this->crudService->find($response, $filterCriteria);
        } catch (\Exception $e) {
            $response->setError(new Error("Error in data save. ". $e->getMessage(), 500));
        }
    }

    public function save(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $rows = $this->crudService->getRowsToSave($request, $this->dataSourceName);
            $this->ger01500municipioservice->saveMunicipio($rows[0]);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function novoCodigoBairro(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $cdbairro = $this->ger01500municipioservice->novoCodigoBairro($row);
            $dataSet = new DataSet('CDBAIRRO', array('CDBAIRRO'=> $cdbairro));
            $response->addDataSet($dataSet);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function novoCodigoRegiao(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $cdregiaomuni = $this->ger01500municipioservice->novoCodigoRegiao($row);
            $dataSet = new DataSet('CDREGIAOMUNI', array('CDREGIAOMUNI'=> $cdregiaomuni));
            $response->addDataSet($dataSet);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function saveLogomarca(Row $row, Response $response) {
        $row = $row->getRow();
        try{
            $response = $this->ger01500municipioservice->saveLogomarca($row);
        } catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function findLogomarca(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $this->dataSourceName = 'logomarca_municipio';
            parent::find($request, $response);
            $this->ger01500municipioservice->setDataSetLogomarca($response);
            $this->dataSourceName = "municipio";
        } catch (\Exception $e) {
            $response->setError(new Error("Error in data save. ". $e->getMessage(), 500));
        }
    }
    
}